${app_name} Nuvola Player App
=============================

Integration of ${app_name} into your linux desktop via
[Nuvola Player](https://github.com/tiliado/nuvolaplayer).
 
Support
-------

Report bugs and issues at <https://github.com/tiliado/nuvola-app-${app_id_dashed}/issues>.

Installation
------------

This project uses [Nuvola SDK](https://github.com/tiliado/nuvolasdk#create-new-project). Please refer to
the [Build a Project Using Nuvola SDK](https://github.com/tiliado/nuvolasdk#build-a-project-using-nuvola-sdk)
page in order to obtain information about dependencies and installation instructions.

Change log
----------

See [CHANGELOG.md](./CHANGELOG.md).

Contributing
------------

See [CONTRIBUTING.md](./CONTRIBUTING.md).

Copyright
---------

  - `src/icon*.svg`
    + Copyright 2011 Alexander King <alexanderddking@gmail.com>
    + Copyright 2011 Arturo Torres Sánchez <arturo.ilhuitemoc@gmail.com>
    + License: [CC-BY-3.0](./LICENSE-CC-BY.txt)

  - Other files:
    + Copyright ${year} ${maintainer_name} <${maintainer_mail}>
    + License: [2-Clause BSD-license](./LICENSE-BSD.txt)
